const path = require('path');

module.exports = {
  /**
   * When we need to customize the paths to resources for each micro site that use this theme
   * we can pass options here by converting this object to a function.
   *
   * This is currently buggy as discussed in this issue:
   * https://github.com/gatsbyjs/gatsby/issues/16142
   */

  siteMetadata: {
    siteUrl: 'https://docs.commercetools.com',
    title: 'commercetools docs',
    description: 'Documentation of the commercetools Platform',
    author: '@commercetools'
  },
  plugins: [
    {
      // This plugin is here to also run page creation over the files in the theme directory.
      // The content of the site packages is loaded via the filesystem sources below.
      resolve: 'gatsby-plugin-page-creator',
      options: {
        path: path.join(__dirname, 'src', 'pages')
      }
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'api-specs',
        path: path.resolve('./src/api-specs/')
      }
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'pages',
        path: path.resolve('./src/pages')
      }
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'images',
        path: path.resolve('./src/images')
      }
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'data',
        path: path.resolve('./src/data')
      }
    },
    'gatsby-transformer-yaml',
    {
      resolve: 'gatsby-plugin-sentry',
      options: {
        dsn: 'https://49b96f5d9e7946f49d5d3fa26822d9f9@sentry.io/1407147',
        environment: process.env.NODE_ENV
      }
    },
    {
      resolve: 'gatsby-plugin-emotion',
      options: {
        // Accepts all options defined by `babel-plugin-emotion` plugin.
      }
    },
    {
      resolve: 'gatsby-plugin-mdx',
      options: {
        extensions: ['.mdx', '.md'],
        gatsbyRemarkPlugins: [
          {
            resolve: 'gatsby-remark-images',
            options: {
              maxWidth: 600
            }
          },
          {
            resolve: 'gatsby-remark-copy-linked-files',
            options: {
              destinationDir: 'files'
            }
          }
        ],
        /**
         * It is necessary to replicate gatsbyRemarkPlugins array in plugins.
         *
         * Issue described here:
         * https://github.com/gatsbyjs/gatsby/issues/15486
         *
         * Solution described here:
         * https://github.com/gatsbyjs/gatsby/issues/15486#issuecomment-510153237
         */
        plugins: [
          {
            resolve: 'gatsby-remark-images',
            options: {
              maxWidth: 600
            }
          },
          {
            resolve: 'gatsby-remark-copy-linked-files',
            options: {
              destinationDir: 'files'
            }
          }
        ],
        rehypePlugins: [
          require('rehype-slug'),
          require('./src/utils/rehype/flat-sectionize')
        ]
      }
    },
    '@commercetools-docs/gatsby-transformer-mdx-introspection',
    'gatsby-plugin-react-helmet',
    'gatsby-transformer-sharp',
    'gatsby-plugin-sharp',
    {
      resolve: 'gatsby-plugin-manifest',
      options: {
        /* eslint-disable camelcase */
        short_name: 'commercetools docs',
        name: 'commercetools platform documentation',
        start_url: '/',
        background_color: '#663399',
        theme_color: '#663399',
        /* eslint-enable camelcase */
        display: 'standalone',
        icon: require.resolve('./src/images/favicons/favicon_original.png') // This path is relative to the root of the site.
      }
    },
    {
      resolve: '@commercetools-docs/gatsby-transformer-raml',
      options: {
        validate: true,
        includeApis: ['import', 'import-storage-api', 'test'],
        annotateConstantLikeEnums: true,
        annotateUnionLikeInheritance: true,
        customNumberScalars: true,
        flattenLibraryNamespaces: true,
        movePropertiesToTop: [
          'id',
          'version',
          'key',
          'createdAt',
          'createdBy',
          'lastModifiedAt',
          'lastModifiedBy'
        ],
        movePropertiesToBottom: ['custom']
      }
    },
    {
      resolve: 'gatsby-plugin-webfonts',
      options: {
        fonts: {
          google: [
            {
              family: 'Roboto',
              variants: ['400', '500', '700'], // Roboto variants: thin=100, light=300, regular=400, medium=500, bold=700, black=900
              subsets: ['latin-ext'],
              fontDisplay: 'swap',
              // strategy: 'selfHosted' // self hosted has issues with pathPrefixed sites
              strategy: 'cdn'
            },
            {
              family: 'Roboto Mono',
              variants: ['400'], // Roboto Mono variants: light=300, regular=400, medium=500, bold=700
              subsets: ['latin'],
              fontDisplay: 'swap',
              // strategy: 'selfHosted' // self hosted has issues with pathPrefixed sites
              strategy: 'cdn'
            }
          ]
        },
        formats: ['woff2', 'woff', 'ttf', 'svg', 'eot'],
        //useMinify: true,
        usePreload: true,
        usePreconnect: false
      }
    },
    {
      resolve: 'gatsby-plugin-google-analytics',
      options: {
        trackingId: 'UA-38285631-3',
        head: false,
        anonymize: true,
        respectDNT: false,
        exclude: []
        // optimizeId: 'YOUR_GOOGLE_OPTIMIZE_TRACKING_ID',
        // experimentId: 'YOUR_GOOGLE_EXPERIMENT_ID',
        // variationId: 'YOUR_GOOGLE_OPTIMIZE_VARIATION_ID',
        // cookieDomain: 'docs.commercetools.com'
      }
    }
    // this (optional) plugin enables Progressive Web App + Offline functionality
    // To learn more, visit: https://gatsby.app/offline
    // 'gatsby-plugin-offline',
  ]
};
