import React from 'react';
import PropTypes from 'prop-types';
import { Provider } from 'react-redux';
import { Global, css } from '@emotion/core';
import { dom } from '@fortawesome/fontawesome-svg-core';

import configureStore from './src/utils/configureStore';

const RootWrapper = ({ element }) => {
  // Instantiating store in `RootWrapper` handler ensures:
  //  - there is fresh store for each SSR page
  //  - it will be called only once in browser, when React mounts
  const store = configureStore();
  return (
    <>
      <Global
        styles={css`
          /*
          * need to call dom.css() so fortawesome css is available from
          * server-side rendering, prevents unexpected ui behaviour of
          * fortawesome icons
          */
          ${dom.css()}
        `}
      />
      <Provider store={store}>{element}</Provider>
    </>
  );
};

RootWrapper.propTypes = {
  element: PropTypes.node.isRequired
};

export default RootWrapper;
