import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';

import { wrapWithErrorBoundary } from '../../error-boundary';
import { readResourceByResourcePath } from '../../../utils/helpers';
import Method from './method';

const ResourceContainer = styled.div`
  display: flex;
  flex-direction: column;
  margin-top: 1rem;
`;

const MethodContainer = styled.div`
  margin: 1rem 0;
`;

let Resource = ({ apiKey, resource }) => {
  const resourceObj = readResourceByResourcePath(apiKey, resource);

  return (
    <ResourceContainer>
      {resourceObj.methods.map(method => {
        return (
          <MethodContainer key={method.method}>
            <Method
              apiKey={apiKey}
              url={resourceObj.absoluteUri}
              method={method}
            />
          </MethodContainer>
        );
      })}
    </ResourceContainer>
  );
};

Resource.propTypes = {
  apiKey: PropTypes.string.isRequired,
  resource: PropTypes.string.isRequired
};

if (!__DEVELOPMENT__) {
  Resource = wrapWithErrorBoundary(Resource);
}

export default Resource;
