import React from 'react';
import PropTypes from 'prop-types';
import { css } from '@emotion/core';

import { H4, Figure } from '../../elements';

const Examples = ({ examples, title }) => {
  if (!examples) {
    throw new Error('Must pass examples props to Examples component.');
  }

  return (
    <div>
      <H4 data-testid="properties-examples-title">{title}</H4>
      <div
        css={css`
          display: flex;
          flex-direction: column;
        `}
      >
        {examples.map(example => {
          return (
            <div
              data-testid={`properties-example-${example.name}`}
              key={example.name}
              css={css`
                display: flex;
                flex-direction: column;
                margin-top: 1.5rem;
              `}
            >
              <p>{example.name ? `${example.name}:` : null}</p>
              <Figure code={example.value} language="json" />
            </div>
          );
        })}
      </div>
    </div>
  );
};

Examples.propTypes = {
  examples: PropTypes.arrayOf(PropTypes.object),
  title: PropTypes.string
};

export default Examples;
