import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { originalTypeDisplayText } from '../../../../utils/helpers';
import { Code, Link } from '../../../elements';

export const PureType = ({ apiKey, property, typeLocations, dataTestId }) => {
  const originalTypeToLinkTo =
    property.type === 'array' && property.items
      ? property.items.originalType
      : property.originalType;

  const typeLocation = typeLocations
    ? typeLocations[`${apiKey}__${originalTypeToLinkTo}`]
    : undefined;

  const originalTypeLocation = typeLocation ? typeLocation.urlAnchorTag : '';
  return (
    <div data-testid={dataTestId ? `${dataTestId}` : null}>
      <div>
        {originalTypeLocation ? (
          <Link href={originalTypeLocation}>
            {originalTypeDisplayText(property)}
          </Link>
        ) : (
          <span>{originalTypeDisplayText(property)}</span>
        )}
      </div>
      <div>
        <Code>{property.type}</Code>
      </div>
    </div>
  );
};

PureType.propTypes = {
  apiKey: PropTypes.string.isRequired,
  property: PropTypes.object.isRequired,
  typeLocations: PropTypes.object,
  dataTestId: PropTypes.string
};

const Type = props => {
  return <PureType {...props} />;
};

const mapStateToProps = state => ({
  typeLocations: state.generic.typeLocations
});

export default connect(mapStateToProps)(Type);
