import React from 'react';
import PropTypes from 'prop-types';

import { css } from '@emotion/core';
import { wrapWithErrorBoundary } from '../../error-boundary';
import { useApiTypes } from '../../../utils/api-docs/use-api-types';
import { filterOutApiTypeSubtypes } from '../../../utils/helpers';
import Container from './container';
import { generateTypeURN } from '../../../utils/api-docs/ctp-urn';

let ApiType = ({ apiKey, type }) => {
  const apiTypes = useApiTypes();

  const apiType = apiTypes.find(apiType => {
    return apiType.apiKey === apiKey && apiType.name === type;
  });

  if (!apiType) {
    throw new Error(`Type with name '${type}' not found in API`);
  }

  const apiTypeSubTypes = filterOutApiTypeSubtypes(apiType, apiTypes);

  return (
    <div
      css={css`
        margin: 1rem 0;
      `}
      id={generateTypeURN(apiType)}
    >
      <Container apiType={apiType} apiTypeSubTypes={apiTypeSubTypes} />
    </div>
  );
};

ApiType.propTypes = {
  apiKey: PropTypes.string.isRequired,
  type: PropTypes.string.isRequired
};

if (!__DEVELOPMENT__) {
  ApiType = wrapWithErrorBoundary(ApiType);
}

export default ApiType;
