import React from 'react';
import PropTypes from 'prop-types';
import { css } from '@emotion/core';

import { pixelsToRems } from '../../../utils/helpers';
import { OnPageAnchor } from './on-page-anchor';
import { H1, H2, H3, H4, H5, H6 } from '../headings';

export const MarkdownH1 = ({ children, id }) => (
  <H1 id={id}>
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H1>
);

MarkdownH1.propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string
};

export const MarkdownH2 = ({ children, id }) => (
  <H2
    css={css`
      margin-top: ${pixelsToRems(56)}rem;
      + *:not(:empty) {
        /* :not(:empty) is not strictly needed because is most cases the margins collapse anyways
           but to set a higher specificity !important would have to be used which should be avoided */
        margin-top: ${pixelsToRems(8)}rem;
      }
      padding-bottom: ${pixelsToRems(8)}rem;
      border-bottom: 1px solid #999999;
    `}
    id={id}
  >
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H2>
);

MarkdownH2.propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string
};

export const MarkdownH3 = ({ children, id }) => (
  <H3
    css={css`
      margin-top: ${pixelsToRems(56)}rem;
      + *:not(:empty) {
        margin-top: ${pixelsToRems(8)}rem;
      }
    `}
    id={id}
  >
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H3>
);

MarkdownH3.propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string
};

const h4style = css`
  margin-top: ${pixelsToRems(32)}rem;
  + *:not(:empty) {
    margin-top: ${pixelsToRems(8)}rem;
  }
`;

export const MarkdownH4 = ({ children, id }) => (
  <H4 css={h4style} id={id}>
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H4>
);

const h4propTypes = {
  children: PropTypes.node.isRequired,
  id: PropTypes.string
};

MarkdownH4.propTypes = h4propTypes;

export const MarkdownH5 = ({ children, id }) => (
  <H5 css={h4style} id={id}>
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H5>
);

MarkdownH5.propTypes = h4propTypes;

export const MarkdownH6 = ({ children, id }) => (
  <H6 css={h4style} id={id}>
    {children}
    <OnPageAnchor href={`#${id}`} />
  </H6>
);

MarkdownH6.propTypes = h4propTypes;

export const MarkdownHeadings = {
  H1: MarkdownH1,
  H2: MarkdownH2,
  H3: MarkdownH3,
  H4: MarkdownH4,
  H5: MarkdownH5,
  H6: MarkdownH6
};
