import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { css } from '@emotion/core';

class ErrorBoundary extends Component {
  constructor(props) {
    super(props);
    this.state = { hasError: false };
  }

  // eslint-disable-next-line no-unused-vars
  static getDerivedStateFromError(error) {
    // Update state so the next render will show the fallback UI.
    return { hasError: true };
  }

  componentDidCatch(error, errorInfo) {
    Sentry.withScope(scope => {
      Object.keys(errorInfo).forEach(key => {
        scope.setExtra(key, errorInfo[key]);
      });
      Sentry.captureException(error);
    });
  }

  render() {
    if (this.state.hasError) {
      //render fallback UI
      return (
        <div
          css={css`
            margin: 1rem 0;
            padding: 0.5rem;
            border: solid 1px red;
            border-radius: 5px;
          `}
        >
          <h2>Something went wrong.</h2>
          <p>Our team has been notified, but click here fill out a report.</p>
          <button onClick={() => Sentry.showReportDialog()}>
            Report feedback
          </button>
        </div>
      );
    }

    return this.props.children;
  }
}

ErrorBoundary.propTypes = {
  children: PropTypes.node.isRequired
};

export default ErrorBoundary;

export const wrapWithErrorBoundary = Component => {
  return function ComponentWrappedWithErrorBoundary(props) {
    return (
      <ErrorBoundary>
        <Component {...props} />
      </ErrorBoundary>
    );
  };
};
