import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';

import logo from '../images/system/ct-cube.svg';
import { headerHeight } from './styles/dimensions';
import { useSiteMetadata } from '../utils/use-site-metadata';

const HeaderElement = styled.header`
  display: flex;
  align-items: center;
  height: ${headerHeight}rem;
  margin: 0 auto;
`;

const SiteLogo = styled.img`
  height: 2rem;
`;

const SiteTitle = styled.span`
  margin-left: 1rem;
  color: #999;
  font-size: 0.875rem;
  line-height: 20px;
`;

const Divider = styled.div`
  height: 2rem;
  width: 0.0625rem;
  background-color: #d8d8d8;
  margin-left: 1.375rem;
`;

export const PureHeader = ({ siteTitle }) => {
  return (
    <HeaderElement>
      <SiteLogo
        id="site-logo"
        src={logo}
        alt="commercetools platform documentation logo"
      />

      <SiteTitle>{siteTitle}</SiteTitle>

      <Divider />
    </HeaderElement>
  );
};

PureHeader.propTypes = {
  siteTitle: PropTypes.string
};

PureHeader.defaultProps = {
  siteTitle: ''
};

const Header = props => {
  const siteTitle = useSiteMetadata().siteMetadata.title;
  return <PureHeader {...props} siteTitle={siteTitle} />;
};

export default Header;
