import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import { css } from '@emotion/core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faInfo } from '@fortawesome/free-solid-svg-icons/faInfo';
import { faExclamationTriangle } from '@fortawesome/free-solid-svg-icons/faExclamationTriangle';
import { faBan } from '@fortawesome/free-solid-svg-icons/faBan';

import { pixelsToRems, markdown2React } from '../utils/helpers';

const Container = styled.div`
  display: flex;
  width: 100%;
  padding: ${pixelsToRems(16)}rem;
  margin: ${pixelsToRems(8)}rem 0;
  border: ${pixelsToRems(1)}rem solid;
  border-radius: ${pixelsToRems(6)}rem;
`;

const IconWrapper = styled.div`
  flex-shrink: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  width: ${pixelsToRems(24)}rem;
  height: ${pixelsToRems(24)}rem;

  svg.default {
    width: ${pixelsToRems(7.73)}rem;
    height: ${pixelsToRems(14.81)}rem;
    color: #078cdf;
  }

  svg.warning {
    width: ${pixelsToRems(18)}rem;
    height: ${pixelsToRems(16.01)}rem;
    color: #f16d0e;
  }

  svg.error {
    width: ${pixelsToRems(18)}rem;
    height: ${pixelsToRems(18)}rem;
    color: #e60050;
    transform: scaleX(-1);
  }
`;

const InfoTextWrapper = styled.div`
  margin-left: ${pixelsToRems(8)}rem;
`;

function Box({ containerCustomStyle, icon, iconClassName, children }) {
  return (
    <Container css={containerCustomStyle}>
      <IconWrapper>
        <FontAwesomeIcon icon={icon} size="xs" className={iconClassName} />
      </IconWrapper>
      <InfoTextWrapper>{markdown2React(children)}</InfoTextWrapper>
    </Container>
  );
}

Box.propTypes = {
  containerCustomStyle: PropTypes.object.isRequired,
  icon: PropTypes.object.isRequired,
  iconClassName: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired
};

export function Info({ children }) {
  const containerCustomStyle = css`
    border-color: #078cdf;
    background-color: #eef4f7;
  `;

  return (
    <Box
      containerCustomStyle={containerCustomStyle}
      icon={faInfo}
      iconClassName="default"
    >
      {children}
    </Box>
  );
}

Info.propTypes = {
  children: PropTypes.node.isRequired
};

export function Warning({ children }) {
  const containerCustomStyle = css`
    border-color: #f16d0e;
    background-color: #fef0e7;
  `;

  return (
    <Box
      containerCustomStyle={containerCustomStyle}
      icon={faExclamationTriangle}
      iconClassName="warning"
    >
      {children}
    </Box>
  );
}

Warning.propTypes = {
  children: PropTypes.node.isRequired
};

export function Error({ children }) {
  const containerCustomStyle = css`
    border-color: #e60050;
    background-color: #ffe5ee;
  `;

  return (
    <Box
      containerCustomStyle={containerCustomStyle}
      icon={faBan}
      iconClassName="error"
    >
      {children}
    </Box>
  );
}

Error.propTypes = {
  children: PropTypes.node.isRequired
};
