import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { MDXProvider } from '@mdx-js/react';

import { useTypeLocations } from '../utils/api-docs/use-type-locations';
import { toggleOpenLeftNav } from '../action-creators/navigation-drawer';
import { setTypeLocations } from '../action-creators/generic';
import Global from './styles/global';
import {
  MarkdownHeadings,
  Img,
  Link,
  BlockQuote,
  Code,
  MarkdownFigure,
  Ul,
  Ol,
  Li,
  ContentTable
} from './elements';
import NavigationDrawer from './navigation-drawer';
import Header from './header';
import LeftNav from './nav/left';
import ApiType from './api/type';
import ApiEndpoint from './api/endpoint';
import ApiEndpointsForResource from './api/endpoints-for-resource';
import { Info, Warning, Error } from './info-box';
import Main from './main';
import { Section } from './elements/section';

const components = {
  section: Section,
  h1: MarkdownHeadings.H2,
  h2: MarkdownHeadings.H3,
  h3: MarkdownHeadings.H4,
  h4: MarkdownHeadings.H5,
  h5: MarkdownHeadings.H6,
  h6: MarkdownHeadings.H6,
  a: Link,
  img: Img,
  ul: Ul,
  ol: Ol,
  li: Li,
  blockquote: BlockQuote,
  inlineCode: Code,
  pre: MarkdownFigure,
  table: ContentTable,
  ApiType,
  ApiEndpoint,
  ApiEndpointsForResource,
  Info,
  Warning,
  Error
};

const Layout = ({
  title,
  children,
  openLeftNavDrawer,
  toggleOpenLeftNav,
  rightNavItems,
  setTypeLocations
}) => {
  setTypeLocations(useTypeLocations());

  return (
    <MDXProvider components={components}>
      <>
        <Global />

        <NavigationDrawer
          header={<Header />}
          leftNav={<LeftNav />}
          openLeftNav={openLeftNavDrawer}
          onClose={handleOnNavigationClose}
        >
          <Main title={title} rightNavItems={rightNavItems}>
            {children}
          </Main>
        </NavigationDrawer>
      </>
    </MDXProvider>
  );

  function handleOnNavigationClose() {
    toggleOpenLeftNav();
  }
};

Layout.propTypes = {
  title: PropTypes.string,
  children: PropTypes.node.isRequired,
  openLeftNavDrawer: PropTypes.bool,
  toggleOpenLeftNav: PropTypes.func,
  rightNavItems: PropTypes.array,
  setTypeLocations: PropTypes.func
};

const mapStateToProps = state => ({
  openLeftNavDrawer: state.navigationDrawer.openLeftNav
});

const mapDispatchToProps = { toggleOpenLeftNav, setTypeLocations };

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(Layout);
