import React from 'react';
import PropTypes from 'prop-types';
import { css } from '@emotion/core';

function LinesClamper({ children, text, lines = 2 }) {
  if (computeType(lines) !== 'number') {
    throw new Error(`"${lines}" must be of type number.`);
  }

  const linesAsInteger = Math.trunc(lines);

  return (
    <span
      css={css`
        /* Weird clamping - https://css-tricks.com/line-clampin/ */
        display: -webkit-box;
        -webkit-line-clamp: ${linesAsInteger};
        -webkit-box-orient: vertical;
        overflow: hidden;
        /* End: Weird clamping */
        margin: 0;
        padding: 0;
      `}
    >
      {children || text}
    </span>
  );

  function computeType(value) {
    var regex = /^\[object (\S+?)\]$/;
    var matches = Object.prototype.toString.call(value).match(regex) || [];

    return (matches[1] || 'undefined').toLowerCase();
  }
}

LinesClamper.propTypes = {
  customProp: (props, propName, componentName) => {
    if (!props.children && !props.text) {
      return new Error(
        `Invalid prop - one of props 'children' or 'text' was not specified in '${componentName}'.`
      );
    }
  },
  children: PropTypes.node,
  text: PropTypes.string,
  lines: PropTypes.number
};

export default LinesClamper;