import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';

import { navContainerBorderRight } from './styles/dimensions';
import { generateAnchorString, pixelsToRems } from '../utils/helpers';
import { MarkdownHeadings } from './elements';
import RightNav from './nav/right';
import Footer from './footer';

const MainElement = styled.main`
  height: 100%;
  padding: 0.8rem 1rem 0 2rem;
  word-break: break-word;
  overflow-y: scroll;
`;

const rightNavContainerWidth = 15.5;
const rightNavMarginLeft = 2;

const TitleContainer = styled.div`
  margin-right: ${rightNavContainerWidth + rightNavMarginLeft}rem;
`;

const ContentAndRightNav = styled.div`
  display: flex;
  justify-content: space-between;
  margin-top: 1rem;
`;

const Article = styled.div`
  line-height: ${pixelsToRems(23)}rem;
  .lead-section {
    margin-bottom: ${pixelsToRems(
    24
  )}rem; /* 80 minus 56px, extra spacing after the lead */
  }
  .sub-subsection {
    margin-left: ${pixelsToRems(23)}rem;
  }
`;

const RightNavContainer = styled.div`
  flex-shrink: 0;
  width: ${rightNavContainerWidth}rem;
  background-color: #fff;
  border-left: ${navContainerBorderRight}rem solid #e6e6e6;
  margin-left: ${rightNavMarginLeft}rem;
`;

const FooterContainer = styled.div`
  margin: 2rem 0 1rem;
`;

function Main({ title, children, rightNavItems }) {
  const titleId = generateAnchorString(title);
  return (
    <MainElement>
      <TitleContainer>
        <MarkdownHeadings.H1 id={titleId}>{title}</MarkdownHeadings.H1>
      </TitleContainer>

      <ContentAndRightNav>
        <Article id="article">{children}</Article>

        {rightNavItems ? (
          <RightNavContainer>
            <RightNav
              title={{ text: title, id: titleId }}
              items={rightNavItems}
            />
          </RightNavContainer>
        ) : null}
      </ContentAndRightNav>

      <FooterContainer>
        <Footer />
      </FooterContainer>
    </MainElement>
  );
}

Main.propTypes = {
  title: PropTypes.string,
  children: PropTypes.node.isRequired,
  rightNavItems: PropTypes.array
};

export default Main;
