import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import { css } from '@emotion/core';

import { sectionLeftPadding } from '../../styles/dimensions/right';
import LinesClamper from '../../lines-clamper';
import SubMenu from './sub-menu';

const selected = css`
  color: #078cdf;
  text-decoration: none;
`;

const MenuItem = styled.div`
  padding-left: ${sectionLeftPadding}rem;

  a {
    display: inline-block;
    width: 100%;
    color: #1a1a1a;
    font-size: 1rem;
    line-height: 1.438rem;
  }

  a:hover {
    ${selected};
  }

  a.selected {
    ${selected};
  }
`;

const subMenuStyle = css`
  margin-left: 2.5rem;
`;

function NavItem({ item, onNavItemClick, selected, ...otherProps }) {
  const subMenuItems = extractSubMenuItems(item.items);

  return (
    <li key={item.url} {...otherProps}>
      <MenuItem>
        <a
          href={item.url}
          onClick={handleClick}
          className={selected ? 'selected' : null}
        >
          <LinesClamper>{item.title}</LinesClamper>
        </a>
      </MenuItem>

      {subMenuItems ? (
        <SubMenu items={subMenuItems} css={subMenuStyle} />
      ) : null}
    </li>
  );

  function handleClick(e) {
    if (onNavItemClick) {
      onNavItemClick(e.target.text);
    }
  }
}

export function extractSubMenuItems(items) {
  let subMenuItems;

  if (items) {
    subMenuItems = [];

    items.forEach(item => {
      if (item.url && item.title) {
        subMenuItems.push({ url: item.url, title: item.title });
      }
    });
  }

  return subMenuItems;
}

NavItem.propTypes = {
  item: PropTypes.shape({
    url: PropTypes.string.isRequired,
    title: PropTypes.string.isRequired,
    items: PropTypes.arrayOf(PropTypes.object)
  }),
  onNavItemClick: PropTypes.func,
  selected: PropTypes.bool
};

export default NavItem;
