import React from 'react';
import PropTypes from 'prop-types';
import styled from '@emotion/styled';
import { css } from '@emotion/core';
import LinesClamper from '../../lines-clamper';

const selected = css`
  text-decoration: underline;
`;

const MenuItem = styled.div`
  a {
    display: inline-block;
    width: 100%;
    color: #666;
    font-size: 0.875rem;
    line-height: 1.25rem;
  }

  a:hover {
    ${selected};
  }

  a.selected {
    ${selected};
  }
`;

function SubMenu({ items, ...otherProps }) {
  return (
    <ul {...otherProps}>
      {items.map(item => (
        <MenuItem key={item.url}>
          <a data-tip={item.title} data-for="right-nav" href={item.url}>
            <LinesClamper>{item.title}</LinesClamper>
          </a>
        </MenuItem>
      ))}
    </ul>
  );
}

SubMenu.propTypes = {
  items: PropTypes.arrayOf(
    PropTypes.shape({
      url: PropTypes.string.isRequired,
      title: PropTypes.string.isRequired,
      items: PropTypes.arrayOf(PropTypes.object)
    })
  )
};

export default SubMenu;
