import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'gatsby';
import { MDXRenderer } from 'gatsby-plugin-mdx';
import { connect } from 'react-redux';

import { setLocation } from '../action-creators/mdx-location';
import { setLeftNavSelected } from '../action-creators/left-nav';
import Layout from '../components/layout';
import SEO from '../components/seo';

const Mdx = ({ data, location, setLocation, setLeftNavSelected }) => {
  const page = data.mdx;
  const title = page.frontmatter.title ? page.frontmatter.title : '';

  // items of the first item is sufficient because we have just one h1 on a page
  // - mdx creates arrays of items with h1s determining length of array.
  const rightNavItems =
    page.tableOfContents && page.tableOfContents.items
      ? page.tableOfContents.items
      : null;

  useEffect(() => {
    const { host, hostname, href, origin, pathname, protocol } = location;
    setLocation({ host, hostname, href, origin, pathname, protocol });
    setLeftNavSelected(pathname);
  });

  return (
    <Layout title={title} rightNavItems={rightNavItems}>
      <SEO
        title={title}
        keywords={
          page.frontmatter.seoKeywords ? page.frontmatter.seoKeywords : []
        }
      />
      <MDXRenderer>{page.body}</MDXRenderer>
    </Layout>
  );
};

Mdx.propTypes = {
  data: PropTypes.object.isRequired,
  location: PropTypes.object.isRequired,
  setLocation: PropTypes.func,
  setLeftNavSelected: PropTypes.func
};

const mapDispatchToProps = { setLocation, setLeftNavSelected };

export default connect(
  undefined,
  mapDispatchToProps
)(Mdx);

export const queryMarkdownPage = graphql`
  query($slug: String!) {
    mdx(fields: { slug: { eq: $slug } }) {
      fields {
        slug
      }
      frontmatter {
        title
      }
      tableOfContents
      body
    }
  }
`;
