import { useApiResources } from '../api-docs/use-api-resources';

export const readResourceByResourcePath = (apiKey, resourcePath) => {
  const resources = useApiResources();

  const resource = resources.find(resource => {
    const actualRelativeUri = `${resource.parentUrl}${resource.relativeUri}`;

    return resource.apiKey === apiKey && actualRelativeUri === resourcePath;
  });

  if (!resource) {
    throw new Error(`Resource '${resource}' not found in API`);
  }

  return resource;
};

export const readMethodOfResourceByResourcePath = (
  apiKey,
  resourcePath,
  method
) => {
  const resource = readResourceByResourcePath(apiKey, resourcePath);

  const methodObj = resource.methods.find(methodObj => {
    return methodObj.method === method.toLowerCase();
  });

  if (!methodObj) {
    throw new Error(
      `Method '${method}' of resource '${resource}' not found in API`
    );
  }

  return { method: methodObj, url: resource.absoluteUri };
};
