const isHastHeading = require('hast-util-heading');

const isHeading = elem => {
  if (elem.type === 'jsx') {
    // will will later want to introspect here and consider certain of our Api generation JSX
    // as section delimiting "headings" that cause a new section to be started.
    // this requires parsing the elem.value string into a DOM (parse5, see MDX introspection plugin)
  }
  return isHastHeading(elem);
};

const sectionClasses = {
  h1: 'section',
  h2: 'subsection',
  h3: 'sub-subsection',
  h4: 'sub-subsection-without-index-nav',
  h5: 'do-not-use-level-five-section',
  h6: 'do-not-use-level-six-section'
};

module.exports = ({
  leadSectionClass = 'lead-section',
  sectionIdPrefix = 'section_'
} = {}) => tree => {
  const newNodes = [];
  let currentSection = {
    type: 'element',
    tagName: 'section',
    properties: {
      class: leadSectionClass
    },
    children: []
  };
  for (let elem of tree.children) {
    if (isHeading(elem)) {
      if (currentSection.children.length > 0) newNodes.push(currentSection);
      currentSection = {
        type: 'element',
        tagName: 'section',
        properties: {
          id: sectionIdPrefix + elem.properties.id,
          class: sectionClasses[elem.tagName]
        },
        children: [elem]
      };
    } else if (elem.type === 'import' || elem.type == 'export') {
      newNodes.push(elem);
    } else {
      currentSection.children.push(elem);
    }
  }
  if (currentSection.children.length > 0) newNodes.push(currentSection);
  tree.children = newNodes;
  return tree;
};
